#!/bin/bash
#Automatically Created by buildpkg 1.6.1
#Maintainer: Thorsten Muehlfelder <thenktor@gmx.de>
#url: http://www.kompozer.net/

######Begin Redundant Code######################################
check_for_root() {
	if [ "$UID" != "0" ]; then
		echo "You need to be root"
		exit 1
	fi
}

clean_dirs () {
        for COMPLETED in src pkg; do
                if [ -e $COMPLETED ]; then
                        rm -rf $COMPLETED
                fi
        done
}

clean_old_builds () {
	for COMPLETED in $package.{tgz,md5,dep}; do
		if [ "$KEEPDEPFILE" = "1" ] && [ $COMPLETED = $package.dep ]; then
			continue
		elif [ -e $COMPLETED ]; then
			rm -rf $COMPLETED
		fi
	done
	clean_dirs
}

set_pre_permissions() {
	cd $startdir/src
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;
}


check_for_menu_compliance() {
	if [ -d "$startdir/pkg/usr/share/applications" ]; then
		cd $startdir/pkg/usr/share/applications
		for desktop in *.desktop; do
			Icon=$(grep -e "^Icon=" $desktop | sed 's/Icon=//')
			if [[ "$Icon" ]]; then
				if [ ! "$Icon" == "${Icon%.*}" ]; then
					sed '/Icon/s/\..*$//' -i $desktop
					Icon=$(grep -e "^Icon=" $desktop | sed 's/Icon=//')
				fi
				if [ -d "$startdir/pkg/usr/share/pixmaps" ]; then
					cd $startdir/pkg/usr/share/pixmaps
					for pixmaps in *; do
						[ -d $pixmaps ] && continue
						[ ! "${pixmaps##*.}" == "png" -a ! "${pixmaps##*.}" == "svg" ] && continue
				 		if [ "${pixmaps%.*}" == "$Icon" ]; then
				 			DIR=$(file $pixmaps | awk -F, '{print $2}' | sed 's/ //g')
							[ o"$DIR" == "o" ] && DIR="scalable"
							mkdir -p $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							mv $pixmaps $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							if [[ ! "$(ls $startdir/pkg/usr/share/pixmaps)" ]]; then
								rm -rf $startdir/pkg/usr/share/pixmaps
							fi
						fi
					done
				fi
				if [ -d "$startdir/pkg/usr/share/icons" ]; then
					cd $startdir/pkg/usr/share/icons
					for icons in *; do
				 		if [ "${icons%.*}" == "$Icon" ]; then
							[ ! "${pixmaps##*.}" == "png" -a ! "${pixmaps##*.}" == "svg" ] && continue
				 			DIR=$(file $icons | awk -F, '{print $2}' | sed 's/ //g')
							[ o"$DIR" == "o" ] && DIR="scalable"
							mkdir -p $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							mv $icons $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
						fi
					done
				fi
			fi
		done
	fi
}


gzip_man_and_info_pages() {
	for DOCS in man info; do
		if [ -d "$startdir/pkg/usr/share/$DOCS" ]; then
			mv $startdir/pkg/usr/share/$DOCS $startdir/pkg/usr/$DOCS
			if [[ ! "$(ls $startdir/pkg/usr/share)" ]]; then
				rm -rf $startdir/pkg/usr/share
			fi
		fi
		if [ -d "$startdir/pkg/usr/$DOCS" ]; then
			# I've never seen symlinks in info pages....
			if [ "$DOCS" == "man" ]; then
				(cd $startdir/pkg/usr/$DOCS
				for manpagedir in $(find . -type d -name "man*" 2> /dev/null) ; do
					( cd $manpagedir
					for eachpage in $( find . -type l -maxdepth 1 2> /dev/null) ; do
						ln -s $( readlink $eachpage ).gz $eachpage.gz
						rm $eachpage
					done )
				done)
			fi
			find $startdir/pkg/usr/$DOCS -type f -exec gzip -9 '{}' \;
		fi
	done
}

set_post_permissions() {
	for DIRS in usr/share/icons usr/doc; do
		if [ -d "$startdir/pkg/$DIRS" ]; then
			if [ "$DIRS" == "usr/doc" ]; then
				find $startdir/pkg/$DIRS -type f -exec chmod 644 {} \;
				find $startdir/pkg/$DIRS -type d -exec chmod 755 {} \;
			fi
		fi
		[ -d $startdir/pkg/$DIRS ] && chown root:root -R $startdir/pkg/$DIRS
	done
	[ -d $startdir/pkg/usr/bin ] && find $startdir/pkg/usr/bin -user root -group bin -exec chown root:root {} \;
}

copy_build_script() {
	mkdir -p $startdir/pkg/usr/src/$pkgname-$pkgver/
	cp $startdir/build-$pkgname.sh $startdir/pkg/usr/src/$pkgname-$pkgver/build-$pkgname.sh
	[ -f $startdir/ZENBUILD ] && cp $startdir/ZENBUILD $startdir/pkg/usr/src/$pkgname-$pkgver/ZENBUILD
}

create_package() {
	ls -lR $startdir/pkg
	cd $startdir/pkg
	/sbin/makepkg -l y -c n $startdir/$package.tgz
	cd $startdir
	md5sum $package.tgz > $startdir/$package.md5
}

strip_binaries() {
	cd $startdir/pkg
	find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
}
#########End Redundant Code#####################################
#########Begin Non Redundant Code##############################

prepare_directory() {
	mkdir $startdir/src
	mkdir -p $startdir/pkg/usr/src/$pkgname-$pkgver
	for SOURCES in ${source[@]}; do
		protocol=$(echo $SOURCES | sed 's|:.*||')
	        file=$(basename $SOURCES | awk -F= '{print $NF}')
		if [ ! -f "$file" ]; then
			if [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
				echo -e "\nDownloading $(basename $SOURCES)\n"
        	                wget $SOURCES -O $file
				if [ ! "$?" == "0" ]; then
					echo "Download failed"
					exit 2
				fi 
			else
				echo "$SOURCES does not appear to be a url nor is it in the directory"
				exit 2
			fi
		fi
		cp -R $file $startdir/src
		if ! [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
			cp -R $startdir/$(basename $SOURCES) $startdir/pkg/usr/src/$pkgname-$pkgver/
		fi
		if [ "${SOURCES##*.}" == "desktop" ]; then
			[[ "$(grep -e "^Categories=[a-zA-Z]*;" $(basename $SOURCES))" ]] && install -D $startdir/$(basename $SOURCES) /home/root/zenbuilds/kompozer/pkg/usr/share/applications/$(basename $SOURCES)
		fi
	done
}

extract_source() {
	cd $startdir/src
	if [[ "$(ls $startdir/src)" ]]; then	
		for FILES in ${source[@]}; do
	        	FILES="$(basename $FILES | awk -F= '{print $NF}')"
			file_type=$(file -biz "$FILES")
			unset cmd
			case "$file_type" in
				*application/x-tar*)
					cmd="tar -xf" ;;
				*application/x-zip*)
					cmd="unzip" ;;
				*application/x-gzip*)
					cmd="gunzip -d -f" ;;
				*application/x-bzip*)
					cmd="bunzip2 -f" ;;
			esac
			if [ "$cmd" != "" ]; then
				echo "$cmd $FILES"
	        	        $cmd $FILES
			fi
		done
	elif [ ! "$source" ]; then
		echo -n "" # lame fix
	else
		echo "no files in the src directory $startdir/src"
		exit 2
	fi
}

build() {
	cd $startdir/src/${pkgname}-$pkgver/mozilla
	sh remove.nonfree || return 1

	# change mozconfig
	sed -i 's^ac_add_options\ --enable-optimize.*ac_add_options\ --enable-optimize="${CFLAGS}"' .mozconfig || return 1
	sed -i 's^export\ CFLAGS.*' .mozconfig || return 1
	sed -i 's^export\ CXXFLAGS.*' .mozconfig || return 1

	# copy icon to right location
	mkdir -p -m 755 $startdir/pkg/usr/share/icons/hicolor/48x48/apps || return 1
	install -o root -g root -m 755 $startdir/kompozer.png $startdir/pkg/usr/share/icons/hicolor/48x48/apps/ || return 1

	# create dektop file
	mkdir -p -m 755 $startdir/pkg/usr/share/applications || return 1
	cat << "EOF" > $startdir/pkg/usr/share/applications/kompozer.desktop
[Desktop Entry]
Version=1.0
Encoding=UTF-8
Name=KompoZer
GenericName=HTML Editor
Comment=Web Site Creator
Exec=kompozer
Icon=kompozer.png
Terminal=false
Type=Application
StartupWMClass=kompozer-bin
X-Desktop-File-Install-Version=0.9
Categories=Application;Development; 
EOF

	# create /usr/lib/kompozer/extensions
	mkdir -p -m 755 $startdir/pkg/usr/lib/kompozer/extensions || return 1
	cat << "EOF" > $startdir/pkg/usr/lib/kompozer/extensions/Extensions.rdf
<?xml version="1.0"?>
<RDF:RDF xmlns:em="http://www.mozilla.org/2004/em-rdf#"
         xmlns:NC="http://home.netscape.com/NC-rdf#"
         xmlns:RDF="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
  <RDF:Description RDF:about="urn:mozilla:theme:{972ce4c6-7e08-4474-a285-3208198ce6fd}"
                   em:version="1.0"
                   em:name="KompoZer (classic)"
                   em:description="KompoZer default theme"
                   em:creator="Linspire Inc."
                   em:homepageURL="http://kompozer.net/"
                   em:internalName="classic/1.0"
                   em:locked="true">
    <em:contributor>Ingolfur Haraldsson</em:contributor>
    <em:contributor>Daniel Glazman</em:contributor>
    <em:contributor>Fabien Cazenave</em:contributor>
    <em:targetApplication RDF:resource="rdf:#$akZaz"/>
  </RDF:Description>
  <RDF:Seq RDF:about="urn:mozilla:extension:root">
  </RDF:Seq>
  <RDF:Description RDF:about="rdf:#$akZaz"
                   em:id="{136c295a-4a5a-41cf-bf24-5cee526720d5}"
                   em:minVersion="0.7"
                   em:maxVersion="1.0" />
  <RDF:Seq RDF:about="urn:mozilla:theme:root">
    <RDF:li RDF:resource="urn:mozilla:theme:{972ce4c6-7e08-4474-a285-3208198ce6fd}"/>
  </RDF:Seq>
</RDF:RDF>
EOF
	echo "theme,{972ce4c6-7e08-4474-a285-3208198ce6fd}" > $startdir/pkg/usr/lib/kompozer/extensions/installed-extensions-processed.txt

	# build
	./configure || return 1
	make -j3 || return 1
	make DESTDIR=$startdir/pkg install || return 1

	# change the default browser
	sed -i 'sDebian-sensible\ browser\ by\ defaultXFCE-sensible\ browser\ by\ defaultg' $startdir/pkg/usr/lib/kompozer/defaults/profile/all.js || return 1
	sed -i 's"/usr/bin/x-www-browser""/usr/bin/xfbrowser4"g' $startdir/pkg/usr/lib/kompozer/defaults/profile/all.js || return 1
	sed -i 'sDebian-sensible\ browser\ by\ defaultXFCE-sensible\ browser\ by\ defaultg' $startdir/pkg/usr/lib/kompozer/defaults/pref/all.js || return 1
	sed -i 's"/usr/bin/x-www-browser""/usr/bin/xfbrowser4"g' $startdir/pkg/usr/lib/kompozer/defaults/pref/all.js || return 1
}

create_slackdesc() {
mkdir $startdir/pkg/install
cat <<"EODESC" >$startdir/pkg/install/slack-desc
kompozer: kompozer - WYSIWYG HTML editor
kompozer: 
kompozer: KompoZer is a complete web authoring system that combines web file
kompozer: management and easy-to-use WYSIWYG web page editing.
kompozer: KompoZer is designed to be extremely easy to use, making it ideal for
kompozer: non-technical computer users who want to create an attractive,
kompozer: professional-looking web site without needing to know HTML or web
kompozer: coding.
kompozer: 
kompozer: 
kompozer: 
EODESC
}

copy_docs() {
	for stuff in ${docs[@]}; do
		if [ ! -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
			mkdir -p $startdir/pkg/usr/doc/$pkgname-$pkgver
		fi
		find $startdir/src -type f -iname "$stuff" -exec cp -R '{}' $startdir/pkg/usr/doc/$pkgname-$pkgver \;
	done
}
detect_dependencies() {
	echo "Detecting dependencies..."
	depends=$(depfinder $startdir/$package.tgz)
	depends="$(echo $depends | sed -e 's/\<nss-nspr\>//' -e 's/,,/,/')"
	depends="$(echo $depends | sed -e 's/\<orbit\>//' -e 's/,,/,/')"
	depends="$(echo $depends | sed -e 's/\<iceweasel\>//' -e 's/,,/,/')"
	depends="$(echo $depends | sed -e 's/\<gcc\>//' -e 's/,,/,/')"
	
	depstring=$depends
	unset FIRST
	for deps in $(echo "${depstring}" | sed 's/,/\n/g' | sort -u); do
		if [[ ! "$FIRST" ]]; then
			finaldeps=$deps,
			FIRST='1'
			continue
		fi
		finaldeps=${finaldeps}${deps},
	done
	echo "$finaldeps" | sed -e 's/^,//' -e 's/,$//' > $startdir/$package.dep
}
create_source_file(){
	[ -f $package.src ] && rm $package.src
	if [ ! -z $sourcetemplate ]; then
		echo $sourcetemplate/ZENBUILD >> $package.src
		echo $sourcetemplate/build-$pkgname.sh >> $package.src
	else
		echo ZENBUILD >> $package.src
		echo build-$pkgname.sh >> $package.src
	fi
	for SOURCES in ${source[@]}; do
		protocol=$(echo $SOURCES | sed 's|:.*||')
		if ! [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
			if [ ! -z $sourcetemplate ]; then
				echo $sourcetemplate/$(basename $SOURCES) >> $package.src
			else
				echo $(basename $SOURCES) >> $package.src
			fi
		else
			echo $SOURCES >> $package.src
		fi
	done
}
post_checks(){
	# Ideas taken from src2pkg :)
	if [ -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
		for DIRS in usr/doc/$pkgname-$pkgver usr/doc; do
			cd $startdir/pkg/$DIRS
			if [[ $(find . -type f) = "" ]] ; then
				cd ..
				rmdir $DIRS
			fi
		done
	fi
	# if the docs weren't deleted ...
	if [ -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
		cd $startdir/pkg/usr/doc/$pkgname-$pkgver
		#remove zero lenght files
		if [[ $(find . -type f -size 0) ]]; then
			echo "Removing some zero lenght files"
			find . -type f -size 0 -exec rm -f {} \;
		fi
	fi
	# check if we need to add code to handle info pages
	if [[ -d $startdir/pkg/usr/info ]] && [[ ! $(grep install-info $startdir/pkg/install/doinst.sh &> /dev/null) ]] ; then
		echo "Found info files - Adding install-info command to doinst.sh"
		INFO_LIST=$(ls -1 $startdir/pkg/usr/info)
		echo "" >> $startdir/pkg/install/doinst.sh
		echo "if [ -x usr/bin/install-info ] ; then" >> $startdir/pkg/install/doinst.sh
		for page in $(echo $INFO_LIST) ; do
			echo " usr/bin/install-info --info-dir=usr/info usr/info/$page 2>/dev/null" >> $startdir/pkg/install/doinst.sh
		done
		echo "fi" >> $startdir/pkg/install/doinst.sh
	fi
	[[ -e $startdir/pkg/usr/info/dir ]] && rm -f $startdir/pkg/usr/info/dir

	if [ -d $startdir/pkg/etc ]; then
		cd $startdir/pkg/
		for conf in $(find ./etc -type f) ; do
			conf=${conf: 2}
			dotnew=( "${dotnew[@]}" "$conf" )
		done
	fi
	if [[ "$dotnew" ]]; then
        for files in ${dotnew[@]} ; do
                fullfile="${startdir}/pkg/${files}"
                if [ -e "$fullfile" ]; then
                        mv $fullfile ${fullfile}.new
                else
                        echo "$fullfile was not found"
                        exit 2
                fi
        done
        cat<<"EODOTNEW" >>$startdir/pkg/install/doinst.sh
#Added by buildpkg 1.6.1
dotnew() {
        NEW="${1}.new"
        OLD="$1"
        if [ ! -e $OLD ]; then
                mv $NEW $OLD
        elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
                rm $NEW
        fi
}
EODOTNEW
for i in ${dotnew[@]}; do
echo "dotnew $i" >> $startdir/pkg/install/doinst.sh
done
fi
}

####End Non Redundant Code############################

#Variables

startdir=$(pwd)
SRC=$startdir/src
PKG=$startdir/pkg

pkgname=kompozer
pkgver=0.7.10
pkgrel=1
zenver=62
arch=i686
package=$pkgname-$pkgver-$arch-$zenver.$pkgrel
source=("http://ovh.dl.sourceforge.net/sourceforge/kompozer/kompozer-0.7.10dfsg-src.tar.gz" "kompozer.png")
sourcetemplate=http://thenktor.dyndns.org/packages/kompozer
docs=(LICENSE LEGAL)
export CFLAGS="-O2 -march=i686 -mtune=i686"
export CXXFLAGS="-O2 -march=i686 -mtune=i686"

#Execution

check_for_root
clean_old_builds
prepare_directory
extract_source
set_pre_permissions
build
if [ ! "$?" = "0" ]; then
	echo "build() failed."
	exit 2
fi
create_slackdesc
post_checks
copy_docs
check_for_menu_compliance
strip_binaries
gzip_man_and_info_pages
set_post_permissions
copy_build_script
create_package
create_source_file
detect_dependencies
echo "Package has been built."
echo "Cleaning pkg and src directories"
clean_dirs
